package ovh.herisson.Clyde.Services;

import org.springframework.core.io.UrlResource;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;
import ovh.herisson.Clyde.Repositories.FileRepository;
import ovh.herisson.Clyde.Tables.StorageFile;
import java.io.IOException;
import org.springframework.core.io.Resource;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.Objects;
import java.util.UUID;

@Service
public class StorageService {


    private final Path rootLocation = Paths.get("cdn/");
    private final FileRepository fileRepo;

    public StorageService(FileRepository filerepo){
        this.fileRepo = filerepo;
    }


    public String store(MultipartFile file) {
        UUID uuid = UUID.randomUUID();
        String stringUuid = uuid.toString() + "." + file.getContentType().split("/",2)[1];

        try {
            if (file.isEmpty()) {
                return null;
            }

            Path destinationFile = this.rootLocation.resolve(Paths.get(stringUuid)).toAbsolutePath();

            if (!destinationFile.getParent().equals(this.rootLocation.toAbsolutePath())) {
                return null;}

            Files.copy(file.getInputStream(), destinationFile,StandardCopyOption.REPLACE_EXISTING);
        }
        catch (IOException e) {
            e.printStackTrace();
            return null;
        }

        String url = this.rootLocation.resolve(Paths.get(Objects.requireNonNull(stringUuid)))
                .normalize().toAbsolutePath().toString();
        System.out.println(url);
        fileRepo.save(new StorageFile(file.getName(),url));

        return url;
    }

    public Path load(String filename) {
        return rootLocation.resolve(filename);
    }

    public Resource loadAsResource(String filename) {
        try {
            Path file = load(filename);
            Resource resource = new UrlResource(file.toUri());
            if (resource.exists() || resource.isReadable()) {
                return resource;
            }
            else {return null;
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

}
